package main

import (
	"query-service/internal/drivers/rpcdriver"
	"query-service/internal/usecases/consume"
	"query-service/internal/usecases/databaseinfo"
	"query-service/internal/usecases/produce"
	"query-service/internal/usecases/request"
	"query-service/pkg/logger"

	"git.science.uu.nl/datastrophe/broker"
	"git.science.uu.nl/datastrophe/keyvaluestore"
	"git.science.uu.nl/datastrophe/query-conversion/aql"
	"github.com/thijsheijden/alice"
)

func main() {
	alice.SetLogging()
	logger.Start()

	// MARK: Create relevant services
	keyValueStore := keyvaluestore.NewDriver()

	// Create new rpc driver
	rpcDriver := rpcdriver.New()

	// MARK: Create alice RabbitMQ services
	broker := broker.NewDriver()

	// Instantiate an implementation of the produce UseCase
	produceService := produce.NewService(broker, keyValueStore)

	// MARK: Create relevant services for consuming a message
	convertQueryService := aql.NewService()

	requestSenderService := request.NewService()

	databaseInfoService := databaseinfo.NewService(rpcDriver)

	consumeService := consume.NewService(broker, produceService, convertQueryService, requestSenderService, databaseInfoService)

	// MARK: Start services
	keyValueStore.Connect()
	produceService.Start()

	go consumeService.Start()

	select {}
}
