package produce

import (
	"context"
	"fmt"
	"query-service/pkg/logger"
)

// PublishMessage will publish the message to the queue retrieved from the key value store, with the given sessionID
func (s *Service) PublishMessage(data *[]byte, sessionID *string) {
	// Use the sessionID to query the key value store to get the queue we need to send this message to
	clientQueueID, ok := s.keyValueStore.Get(context.Background(), *sessionID).(string)
	if !ok {
		return
	}

	logger.Log(fmt.Sprintf("Found client queue %s for session %s", clientQueueID, *sessionID))

	// If this client has now disconnected
	if clientQueueID == "" {
		// TODO: Decide whether to throw away the message or perhaps cache it, for now throw it away
		logger.Log("No client updater queue ID")
		return
	}

	headers := make(map[string]interface{})
	headers["sessionID"] = *sessionID
	headers["type"] = "queryResult"
	s.producerDriver.PublishMessage(data, clientQueueID, &headers)
}
